SystemOrganization addCategory: #'NetworkTests-Kernel'!
SystemOrganization addCategory: #'NetworkTests-Protocols'!
SystemOrganization addCategory: #'NetworkTests-RFC822'!
SystemOrganization addCategory: #'NetworkTests-URI'!
SystemOrganization addCategory: #'NetworkTests-UUID'!
SystemOrganization addCategory: #'NetworkTests-Url'!

ClassTestCase subclass: #MIMEDocumentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 6/29/2017 11:51'!
testCharset
	
	| document |
	document := MIMEDocument contentType: 'text/plain;charset=utf-8' content: self utf8String.
	self assert: 'utf-8' equals: document charset. ! !

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 6/29/2017 11:50'!
testContentType
	
	| document |
	document := MIMEDocument contentType: 'text/plain;charset=utf-8' content: self utf8String.
	self assert: 'text/plain' equals: document contentType. ! !

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 6/29/2017 11:42'!
testMainAndSubType
	
	| document |
	document := MIMEDocument contentType: 'text/plain' content: self utf8String.
	self assert: 'text' equals: document mainType. 
	self assert: 'plain' equals: document subType.! !

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 6/29/2017 13:50'!
testMultipartDocument
	
	| document |
	document := MIMEDocument newMultipart.
	self assert: 'multipart/mixed' equals: document contentType. ! !

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 6/29/2017 11:58'!
testParameterizedContentType
	
	| document |
	document := MIMEDocument contentType: 'text/plain;charset=utf-8' content: self utf8String.
	self assert: 'text/plain;charset=utf-8' equals: document parameterizedContentType. ! !

!MIMEDocumentTest methodsFor: 'tests' stamp: 'pre 4/19/2017 12:01'!
testUtf8Text
	
	| document |
	document := MIMEDocument contentType: 'text/plain; charset="utf8"' content: self utf8String.
	self assert: self utf8String utf8ToSqueak equals: document content ! !

!MIMEDocumentTest methodsFor: 'fixtures' stamp: 'pre 4/21/2017 09:06'!
utf8String

	^ #[199 161 84 83 67 72] asString! !

ClassTestCase subclass: #SocketStreamTest
	instanceVariableNames: 'clientStream serverStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!SocketStreamTest methodsFor: 'running' stamp: 'ar 8/2/2010 18:10'!
setUp
	| listener clientSocket serverSocket |
	listener := Socket newTCP.
	[listener listenOn: 0 backlogSize: 4.

	clientSocket := Socket newTCP.
	clientSocket connectTo: #[127 0 0 1] port: listener localPort.
	clientSocket waitForConnectionFor: 1.
	self assert: clientSocket isConnected.

	serverSocket := listener waitForAcceptFor: 1.
	self assert: serverSocket isConnected.
	] ensure:[listener destroy].

	clientStream := SocketStream on: clientSocket.
	serverStream := SocketStream on: serverSocket.
! !

!SocketStreamTest methodsFor: 'running' stamp: 'ar 8/2/2010 17:59'!
tearDown
	clientStream ifNotNil:[clientStream destroy].
	serverStream ifNotNil:[serverStream destroy].! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoClose
	"Ensure that #next:into: will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoCloseNonSignaling
	"Ensure that #next:into: will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpTo
	"Tests correct behavior of #upTo:"

	clientStream nextPutAll:'A line of text', String cr, 'with more text'; flush.
	self assert: (serverStream upTo: Character cr) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String cr; flush] fork.
	self assert: (serverStream upTo: Character cr) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upTo: Character cr] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upTo: Character cr] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:29'!
testUpToAll
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text', String crlf, 'with more text'; flush.
	self assert: (serverStream upToAll: String crlf) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String crlf; flush] fork.
	self assert: (serverStream upToAll: String crlf) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:02'!
testUpToAllAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upToAll: String crlf] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:26'!
testUpToAllAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upToAll: String crlf] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/22/2010 13:28'!
testUpToAllAsciiVsBinary
	"Tests correct behavior of #upToAll"

	serverStream ascii.
	clientStream nextPutAll:'A line of text', String crlf, 'with more text'; flush.
	self assert: (serverStream upToAll: #[13 10]) = 'A line of text'.

	serverStream binary.
	clientStream nextPutAll: String crlf; flush.
	self assert: (serverStream upToAll: String crlf) asString = 'with more text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:47'!
testUpToAllCrlfAscii
	"Tests correct behavior of #upToAll with a two-byte delimiter in ascii mode"
	self testUpToAllDelimiter: String crlf
		input: 'A header', String crlf, 'and a body'
		expected: {'A header'. 'and a body'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:48'!
testUpToAllCrlfBinary
	"Tests correct behavior of #upToAll with a two-byte delimiter in binary mode"
	self testUpToAllDelimiter: String crlf
		input: 'A header', String crlf, 'and a body'
		expected: {'A header'. 'and a body'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:47'!
testUpToAllCrlfCrlfAscii
	"Tests correct behavior of #upToAll with a four-byte delimiter in ascii mode"
	self testUpToAllDelimiter: String crlfcrlf
		input: 'A header', String crlfcrlf, 'and a body'
		expected: {'A header'. 'and a body'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:47'!
testUpToAllCrlfCrlfBinary
	"Tests correct behavior of #upToAll with a four-byte delimiter in binary mode"
	self testUpToAllDelimiter: String crlfcrlf
		input: 'A header', String crlfcrlf, 'and a body'
		expected: {'A header'. 'and a body'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:39'!
testUpToAllDelimiter: delimiter input: input expected: aCollection binary: useBinary
	"General test of #upToAll."
	clientStream nextPutAll: input; close.
	serverStream shouldSignal: false.
	useBinary ifTrue: [serverStream binary] ifFalse: [serverStream ascii].
	aCollection do: [:expected | | actual |
		actual := (serverStream upToAll: delimiter) asString.
		self assert: actual = expected].
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:41'!
testUpToAllEmptyPatternAscii
	"Tests correct behavior of #upToAll with an empty delimiter string, in ascii mode"
	self testUpToAllDelimiter: ''
		input: 'xaxbxc'
		expected: {'xaxbxc'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:41'!
testUpToAllEmptyPatternBinary
	"Tests correct behavior of #upToAll with an empty delimiter string, in binary mode"
	self testUpToAllDelimiter: ''
		input: 'xaxbxc'
		expected: {'xaxbxc'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:48'!
testUpToAllLimit
	"Tests correct behavior of #upToAll:limit:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upToAll: String crlf limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:43'!
testUpToAllLongPatternAscii
	"Tests correct behavior of #upToAll with a long delimiter string, in ascii mode"
	self testUpToAllDelimiter: 'xxxxx'
		input: 'xxxxxaxxxxbxxxxxc'
		expected: {''. 'axxxxb'. 'c'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:43'!
testUpToAllLongPatternBinary
	"Tests correct behavior of #upToAll with a long delimiter string, in binary mode"
	self testUpToAllDelimiter: 'xxxxx'
		input: 'xxxxxaxxxxbxxxxxc'
		expected: {''. 'axxxxb'. 'c'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:45'!
testUpToAllMediumPatternAscii
	"Tests correct behavior of #upToAll with a two-character delimiter string, in ascii mode"
	self testUpToAllDelimiter: 'xx'
		input: 'xxaxbxxc'
		expected: {''. 'axb'. 'c'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:45'!
testUpToAllMediumPatternBinary
	"Tests correct behavior of #upToAll with a two-character delimiter string, in binary mode"
	self testUpToAllDelimiter: 'xx'
		input: 'xxaxbxxc'
		expected: {''. 'axb'. 'c'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:40'!
testUpToAllShortPatternAscii
	"Tests correct behavior of #upToAll with a short delimiter string, in ascii mode"
	self testUpToAllDelimiter: 'x'
		input: 'xaxbxc'
		expected: {''. 'a'. 'b'. 'c'}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:42'!
testUpToAllShortPatternAscii2
	"Tests correct behavior of #upToAll with a short delimiter string, in ascii mode"
	self testUpToAllDelimiter: 'x'
		input: 'axbxcx'
		expected: {'a'. 'b'. 'c'. ''}
		binary: false.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:38'!
testUpToAllShortPatternBinary
	"Tests correct behavior of #upToAll with a short delimiter string, in binary mode"
	self testUpToAllDelimiter: 'x'
		input: 'xaxbxc'
		expected: {''. 'a'. 'b'. 'c'}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'tonyg 2/19/2017 11:42'!
testUpToAllShortPatternBinary2
	"Tests correct behavior of #upToAll with a short delimiter string, in binary mode"
	self testUpToAllDelimiter: 'x'
		input: 'axbxcx'
		expected: {'a'. 'b'. 'c'. ''}
		binary: true.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:11'!
testUpToAllTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upToAll: String crlf] raise: ConnectionTimedOut.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/22/2010 13:28'!
testUpToAsciiVsBinary
	"Tests correct behavior of #upTo:"

	serverStream ascii.
	clientStream nextPutAll:'A line of text', String cr, 'with more text'; flush.
	self assert: (serverStream upTo: 13) = 'A line of text'.

	serverStream binary.
	clientStream nextPutAll: String cr; flush.
	self assert: (serverStream upTo: Character cr) asString = 'with more text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndClose
	"Ensure that #upToEnd will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndCloseNonSignaling
	"Ensure that #upToEnd will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:49'!
testUpToMax
	"Tests correct behavior of #upToAll:max:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upTo: Character cr limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'tests - stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upTo: Character cr] raise: ConnectionTimedOut.
! !

ClassTestCase subclass: #TestURI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-URI'!

!TestURI commentStamp: 'pre 4/22/2022 21:05' prior: 0!
Some parsers allow the scheme name to be present in a relative URI if
   it is the same as the base URI scheme.  This is considered to be a
   loophole in prior specifications of partial URI [RFC1630]. Its use
   should be avoided.

      http:g        =  http:g           ; for validating parsers
                    |  http://a/b/c/g   ; for backwards compatibility
!

!TestURI class methodsFor: 'test generation' stamp: 'mir 2/27/2002 16:13'!
generateAbnormalResolverTests
	"TestURI generateAbnormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('../../../g' 'http://a/../g' )
		#('../../../../g' 'http://a/../../g' )
		#('/./g' 'http://a/./g' )
		#('/../g' 'http://a/../g' )
		#('g.' 'http://a/b/c/g.' )
		#('.g' 'http://a/b/c/.g' )
		#('g..' 'http://a/b/c/g..' )
		#('..g' 'http://a/b/c/..g' )
		#('./../g' 'http://a/b/g' )
		#('./g/.' 'http://a/b/c/g/' )
		#('g/./h' 'http://a/b/c/g/h' )
		#('g/../h' 'http://a/b/c/h' )
		#('g;x=1/./y' 'http://a/b/c/g;x=1/y' )
		#('g;x=1/../y' 'http://a/b/c/y' )
		#('g?y/./x' 'http://a/b/c/g?y/./x' )
		#('g?y/../x' 'http://a/b/c/g?y/../x' )
		#('g#s/./x' 'http://a/b/c/g#s/./x' )
		#('g#s/../x' 'http://a/b/c/g#s/../x' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveAbnormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI class methodsFor: 'test generation' stamp: 'mir 2/27/2002 14:42'!
generateNormalResolverTests
	"TestURI generateNormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('g:h' 'g:h' )
		#('g' 'http://a/b/c/g' )
		#('./g' 'http://a/b/c/g' )
		#('g/' 'http://a/b/c/g/' )
		#('/g' 'http://a/g' )
		#('//g' 'http://g' )
		#('?y' 'http://a/b/c/?y' )
		#('g?y' 'http://a/b/c/g?y' )
		#('g#s' 'http://a/b/c/g#s' )
		#('g?y#s' 'http://a/b/c/g?y#s' )
		#(';x' 'http://a/b/c/;x' )
		#('g;x' 'http://a/b/c/g;x' )
		#('g;x?y#s' 'http://a/b/c/g;x?y#s' )
		#('.' 'http://a/b/c/' )
		#('./' 'http://a/b/c/' )
		#('..' 'http://a/b/' )
		#('../' 'http://a/b/' )
		#('../g' 'http://a/b/g' )
		#('../..' 'http://a/' )
		#('../../' 'http://a/' )
		#('../../g' 'http://a/g' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveNormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI methodsFor: 'coverage' stamp: 'pre 4/22/2022 20:38'!
classToBeTested

	^ URI! !

!TestURI methodsFor: 'tests - file' stamp: 'mir 6/20/2005 17:17'!
testDefaultDirRoundtrip
	| defaultDir defaultURI uriDir |
	defaultDir := FileDirectory default.
	defaultURI := defaultDir uri.
	uriDir := FileDirectory uri: defaultURI.
	self should: [defaultDir fullName = uriDir fullName]! !

!TestURI methodsFor: 'tests - file' stamp: 'ar 4/12/2010 21:38'!
testDirWithHash
	"Tests proper escaping of directories with hash mark"

	| uriDir origPath origDir dirURI |
	origPath := FileDirectory default pathName, '#123'.
	origDir := FileDirectory on: origPath.
	self assert: origDir pathName = origPath.

	dirURI := origDir uri.
	uriDir := FileDirectory uri: dirURI.
	self assert: origDir fullName = uriDir fullName.! !

!TestURI methodsFor: 'tests - file' stamp: 'mir 6/20/2005 17:19'!
testDirectoryRoot

	| rootDir uriRoot uriDir |
	rootDir := FileDirectory root.
	uriRoot := 'file:///' asURI.
	uriDir := FileDirectory uri: uriRoot.
	self should: [rootDir fullName = uriDir fullName]! !

!TestURI methodsFor: 'tests - comparing' stamp: 'pre 4/22/2022 20:46'!
testEquals

	| uri uriString |
	uri := [:string | URI fromString: string].

	uriString := 'http://squeak.org/'.
	self assert: (uri value: uriString) = (uri value: uriString).
	uriString := 'http://squeak.org/index.html'.
	self assert: (uri value: uriString) = (uri value: uriString).
	uriString := 'mailto:somebody@somewhere.nowhere#fragment'.
	self assert: (uri value: uriString) = (uri value: uriString).
	
	self deny: (uri value: 'http://squeak.org') = (uri value: 'http://website.com').! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g/.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/./h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/h'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/../h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/h'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/./y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x=1/y'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/../y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/y'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/./x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 16:12'!
testResolveAbnormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/../x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/./x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/../x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../../g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/./g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/./g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g.'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/.g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g..'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/..g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g:h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'g:h'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y#s'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := ';x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/;x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x?y#s'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal19
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal20
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal21
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '//g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://g'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/?y'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y'].
! !

!TestURI methodsFor: 'tests - resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s'].
! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:21'!
testSchemeAbsoluteFail1
	self should: [URI fromString: 'http:'] raise: IllegalURIException! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:24'!
testSchemeAbsolutePass1
	| uri |
	uri := URI fromString: 'http://www.squeakland.org'.
	self should: [uri scheme = 'http'].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self shouldnt: [uri isRelative]! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:25'!
testSchemeAbsolutePass2
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere'.
	self should: [uri scheme = 'mailto'].
	self should: [uri isAbsolute].
	self should: [uri isOpaque].
	self shouldnt: [uri isRelative]! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:32'!
testSchemeAbsolutePass3
	| uri |
	uri := URI fromString: 'ftp://ftp@squeak.org'.
	self should: [uri scheme = 'ftp'].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self shouldnt: [uri isRelative].
	self should: [uri userInfo = 'ftp'].
	self should: [uri host = 'squeak.org'].
	self should: [uri port isNil].
! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:38'!
testSchemeAbsolutePass4
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere#fragment'.
	self should: [uri scheme = 'mailto'].
	self should: [uri isAbsolute].
	self should: [uri isOpaque].
	self shouldnt: [uri isRelative].
	self should: [uri fragment = 'fragment'].
! !

!TestURI methodsFor: 'tests - parsing' stamp: 'mir 2/20/2002 17:39'!
testSchemeAbsolutePass5
	| uri |
	uri := URI fromString: 'http://www.squeakland.org#fragment'.
	self should: [uri scheme = 'http'].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self shouldnt: [uri isRelative].
	self should: [uri fragment = 'fragment'].
! !

ClassTestCase subclass: #UrlSubclassesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

UrlSubclassesTest subclass: #FileUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!FileUrlTest methodsFor: 'coverage' stamp: 'pre 4/22/2022 15:57'!
classToBeTested

	^ FileUrl! !

!FileUrlTest methodsFor: 'private' stamp: 'pre 4/22/2022 15:51'!
createUrlFrom: aString

	^ FileUrl absoluteFromText: aString! !

!FileUrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 12:43'!
testAsString
	| target url |
	target := 'file://localhost/etc/rc.conf'.
	url := target asUrl.
	self assert: url asString = target.
		! !

!FileUrlTest methodsFor: 'tests' stamp: 'pre 4/22/2022 15:52'!
testEqual

	self 
		assertUrl: 'file:///C:/Users/Uniform%20Resource%20Identifier.html'
		equals: 'file:///C:/Users/Uniform%20Resource%20Identifier.html'.
	
	self 
		denyUrl: 'file:///C:/Users/Uniform%20Resource%20Identifier.html'
		equals: 'file:///C:/Users/Uniform%20Resource%20Identifier2.html'.! !

!FileUrlTest methodsFor: 'tests' stamp: 'pre 4/22/2022 15:54'!
testEqualWithHostAndFragment

	self 
		assertUrl: 'file://localhost/C:/Users/Uniform%20Resource%20Identifier.html#heading1' 
		equals: 'file://localhost/C:/Users/Uniform%20Resource%20Identifier.html#heading1'.
	
	self 	
		denyUrl: 'file://localhost/C:/Users/Uniform%20Resource%20Identifier.html#heading1' 
		equals: 'file://localhost/C:/Users/Uniform%20Resource%20Identifier.html#heading2'.
		
	self 	
		denyUrl: 'file://localhost/C:/Users/Uniform%20Resource%20Identifier.html#heading1' 
		equals: 'file://localhost2/C:/Users/Uniform%20Resource%20Identifier.html#heading1'.! !

!FileUrlTest methodsFor: 'tests' stamp: 'ct 11/14/2020 19:42'!
testRetrieveContents

	| content name |
	name := '{1}-{2}.txt' format: {self className. self selector}.
	content := self identityHash asString.
	
	FileStream newFileNamed: name do: [:stream |
		stream nextPutAll: content].
	[self assert: content equals:
		(FileUrl absoluteFromFileNameOrUrlString: name) retrieveContents content]
			ensure: [FileDirectory default deleteFileNamed: name].! !

UrlSubclassesTest subclass: #GenericUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!GenericUrlTest methodsFor: 'coverage' stamp: 'pre 4/22/2022 20:47'!
classToBeTested

	^ GenericUrl! !

!GenericUrlTest methodsFor: 'private' stamp: 'pre 4/22/2022 16:02'!
createUrlFrom: aString 
	
	^ GenericUrl absoluteFromText: aString! !

!GenericUrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 12:56'!
testAsString
	| url |
	url := GenericUrl new schemeName: 'sip' locator: 'foo@bar'.
	self assert: url asString = 'sip:foo@bar'.! !

!GenericUrlTest methodsFor: 'tests' stamp: 'pre 4/22/2022 16:09'!
testEqual

	self 
		assertUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
	
	"Different port"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'http://nobody:password@example.org:8081/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
		
	"Different host"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'http://nobody:password@example2.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
		
	"Different query"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86#section_2'
		equals: 'http://nobody:password@example2.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
		
	"Different fragment"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'http://nobody:password@example2.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section'.
		
	"Different authentication"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'http://someone:password@example2.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
		
	"Different schema"
	self 
		denyUrl: 'http://nobody:password@example.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'
		equals: 'sometp://someone:password@example2.org:8080/cgi-bin/script.php?action=submit&pageid=86392001#section_2'.
	
		! !

UrlSubclassesTest subclass: #HierarchicalUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!HierarchicalUrlTest methodsFor: 'coverage' stamp: 'pre 4/22/2022 20:47'!
classToBeTested

	^ HierarchicalUrl! !

!HierarchicalUrlTest methodsFor: 'private' stamp: 'pre 4/22/2022 16:12'!
createUrlFrom: aString 
	
	^ HierarchicalUrl absoluteFromText: aString! !

!HierarchicalUrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:03'!
testAsString
	| url |
	url := HierarchicalUrl new
		schemeName: 'ftp'
		authority: 'localhost'
		path: #('path' 'to' 'file')
		query: 'aQuery'.
	self assert: url asString = 'ftp://localhost/path/to/file?aQuery'.! !

!HierarchicalUrlTest methodsFor: 'tests' stamp: 'pre 4/22/2022 16:15'!
testEqual
	
	self
		assertUrl: 'ftp://localhost/path/to/file?aQuery'
		equals: 'ftp://localhost/path/to/file?aQuery'.
		
	"Different Schema name"
	self
		denyUrl: 'ftp://localhost/path/to/file?aQuery'
		equals: 'http://localhost/path/to/file?aQuery'.
	
	"Different Authority"
	self
		denyUrl: 'ftp://localhost/path/to/file?aQuery'
		equals: 'ftp://remotehost/path/to/file?aQuery'.
	
	"Different Path"
	self
		denyUrl: 'ftp://localhost/path/to/file?aQuery'
		equals: 'ftp://localhost/anotherpath/to/file?aQuery'.
	
	"Different Query"
	self
		denyUrl: 'ftp://localhost/path/to/file?aQuery'
		equals: 'ftp://localhost/path/to/file?aQuery=aValue'.
! !

UrlSubclassesTest subclass: #HttpUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!HttpUrlTest methodsFor: 'coverage' stamp: 'pre 4/22/2022 20:47'!
classToBeTested

	^ HttpUrl! !

!HttpUrlTest methodsFor: 'private' stamp: 'pre 4/22/2022 16:21'!
createUrlFrom: aString 
	
	^ HttpUrl absoluteFromText: aString! !

!HttpUrlTest methodsFor: 'tests' stamp: 'pre 4/22/2022 16:23'!
testEqual
	
	self
		assertUrl: 'http://localhost/path/to/file?aQuery'
		equals: 'http://localhost/path/to/file?aQuery'.
		
	"Different Schema name"
	self
		denyUrl: 'http://localhost/path/to/file?aQuery'
		equals: 'https://localhost/path/to/file?aQuery'.
	
	"Different Authority"
	self
		denyUrl: 'http://localhost/path/to/file?aQuery'
		equals: 'http://remotehost/path/to/file?aQuery'.
	
	"Different Path"
	self
		denyUrl: 'http://localhost/path/to/file?aQuery'
		equals: 'http://localhost/anotherpath/to/file?aQuery'.
	
	"Different Query"
	self
		denyUrl: 'http://localhost/path/to/file?aQuery'
		equals: 'http://localhost/path/to/file?aQuery=aValue'.
! !

!HttpUrlTest methodsFor: 'tests' stamp: 'ar 9/1/2010 00:31'!
testHttps
	self assert: 'https://encrypted.google.com' asUrl class == HttpUrl! !

!UrlSubclassesTest class methodsFor: 'Testing' stamp: 'pre 4/22/2022 16:00'!
isAbstract

	^ self = UrlSubclassesTest! !

!UrlSubclassesTest methodsFor: 'assertions' stamp: 'pre 4/22/2022 16:22'!
assertUrl: aString equals: anotherString

	self 
		assert: (self createUrlFrom: aString) = (self createUrlFrom: anotherString)
		description: ('Url {1} is not equal to {2}' format: {aString . anotherString}).! !

!UrlSubclassesTest methodsFor: 'private' stamp: 'pre 4/22/2022 15:57'!
createUrlFrom: aString

	self subclassResponsibility.! !

!UrlSubclassesTest methodsFor: 'assertions' stamp: 'pre 4/22/2022 16:22'!
denyUrl: aString equals: anotherString

	self 
		deny: (self createUrlFrom: aString) = (self createUrlFrom: anotherString)
		description: ('Url {1} is equal to {2} but should not be.' format: {aString . anotherString}).! !

ClassTestCase subclass: #UrlTest
	instanceVariableNames: 'url baseUrl expected string'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!UrlTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class Url. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- http://minnow.cc.gatech.edu/squeak/1547
	- the sunit class category!

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:58'!
testAbsoluteBrowser

	url := Url absoluteFromText: 'browser:bookmarks#mainPart'.

	self assert: url schemeName = 'browser'.
	self assert: url locator = 'bookmarks'.
	self assert:url fragment = 'mainPart'.
	self assert: url class = BrowserUrl.
	! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:29'!
testAbsoluteFILE
	
	url := Url absoluteFromText: 'file:/etc/passwd#foo'.

	self assert: url schemeName = 'file'.
	self assert: url path first = 'etc'.
	self assert: url path size = 2.	
	self assert: url fragment = 'foo'.! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:32'!
testAbsoluteFILE2
	
	url := 'fILE:/foo/bar//zookie/?fakequery/#fragger' asUrl.

	self assert: url schemeName = 'file'.
	self assert: url class = FileUrl.
	self assert: url path first ='foo'.
	self assert: url path size = 5.
	self assert: url fragment = 'fragger'.! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'gk 2/12/2004 21:30'!
testAbsoluteFILE3
	"Just a few selected tests for FileUrl, not complete by any means."


	{'file:'. 'file:/'. 'file://'} do: [:s |
	 	url := FileUrl absoluteFromText: s.
		self assert: (url asString = 'file:///').
		self assert: (url host = '').
		self assert: url isAbsolute].
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'file:///dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: (url host = '').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: '/dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self deny: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/dir/file.txt'.
	self assert: (url asString = 'file:///c%3A/dir/file.txt').
	self assert: url isAbsolute.
	
	"Only a drive letter doesn't refer to a directory."
	url := FileUrl absoluteFromText: 'c:'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:05'!
testAbsoluteFTP
	
	url := 'ftP://some.server/some/directory/' asUrl.

	self assert: url schemeName = 'ftp'.
	self assert: url class = FtpUrl.
	self assert: url authority = 'some.server'.	
	self assert: url path first = 'some'.
	self assert: url path size  = 3.
	! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:05'!
testAbsoluteHTTP
	
	url := 'hTTp://chaos.resnet.gatech.edu:8000/docs/java/index.html?A%20query%20#part' asUrl.

	self assert: url schemeName = 'http'.
	self assert: url authority = 'chaos.resnet.gatech.edu'.
	self assert: url path first = 'docs'.
	self assert: url path size = 3.
	self assert: url query = 'A%20query%20'.
	self assert: url fragment = 'part'.! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'fbs 11/6/2013 08:45'!
testAbsolutePortErrorFix
	"This should not throw an exception."
	Url absoluteFromText: 'http://swikis.ddo.jp:8823/'.

	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:-1/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:65536/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:auau/'] raise: Error.! !

!UrlTest methodsFor: 'tests - absolute urls' stamp: 'md 4/21/2003 13:08'!
testAbsoluteTELNET
	
	url := 'telNet:chaos.resnet.gatech.edu#goo' asUrl.

	self assert: url schemeName = 'telnet'.
	self assert: url locator = 'chaos.resnet.gatech.edu'.
	self assert: url fragment = 'goo'.	
! !

!UrlTest methodsFor: 'tests' stamp: 'st 9/27/2004 15:48'!
testCombineWithRelative
	#(#('http://www.rfc1149.net/' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/index.html' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/devel/' '../sam/' 'http://www.rfc1149.net/sam/') #('http://www.rfc1149.net/devel/index.html' '../sam/' 'http://www.rfc1149.net/sam/')) 
		do: [:a | self assert: (Url combine: a first withRelative: a second) = a third]! !

!UrlTest methodsFor: 'tests' stamp: 'bp 2/12/2005 20:21'!
testFromFileNameOrUrlString

	url := Url absoluteFromFileNameOrUrlString: 'asdf'.
	self assert: url schemeName = 'file'.
	self assert: url fragment isNil.
	self assert: url class = FileUrl.

	url := Url absoluteFromFileNameOrUrlString: 'http://209.143.91.36/super/SuperSwikiProj/AAEmptyTest.001.pr'.
	self assert: url schemeName = 'http'.
	self assert: url fragment isNil.
	self assert: url class = HttpUrl.! !

!UrlTest methodsFor: 'tests - relative' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFILE
	
	| url2 |
	baseUrl := 'file:/some/dir#fragment1' asUrl.
	url := baseUrl newFromRelativeText: 'file:../another/dir/#fragment2'.
	self assert: url asText =  'file:///another/dir/#fragment2'.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'file://hostname/flip/file.txt'.
	url2 privateInitializeFromText: '../file2.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/file2.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'flip/file.txt'.
	self deny: url2 isAbsolute.
	url2 privateInitializeFromText: '.././flip/file.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/flip/file.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
! !

!UrlTest methodsFor: 'tests - relative' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp://a.b'.

	self assert: url asString =  'ftp://a.b/'.! !

!UrlTest methodsFor: 'tests - relative' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP2
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp:xyz'.


	self assert: url asString =  'ftp://somewhere/some/dir/xyz'.! !

!UrlTest methodsFor: 'tests - relative' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP3
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'http:xyz'.

	self assert: url asString = 'http://xyz/'.! !

!UrlTest methodsFor: 'tests - relative' stamp: 'fbs 2/2/2005 13:21'!
testRelativeHTTP
	
	baseUrl := 'http://some.where/some/dir?query1#fragment1' asUrl.
	url := baseUrl newFromRelativeText: '../another/dir/?query2#fragment2'.

	self assert: url asString =  'http://some.where/another/dir/?query2#fragment2'.! !

!UrlTest methodsFor: 'tests' stamp: 'gk 2/12/2004 21:31'!
testRoundTripFILE
	"File URLs should round-trip OK. This test should ultimately be
	tested on all platforms."

	| fileName |
	fileName := FileDirectory default fullNameFor: 'xxx.st'.
	url := FileDirectory urlForFileNamed: fileName.
	self assert: (url pathForFile = fileName) description: 'fileName didn''t round-trip'.! !

!UrlTest methodsFor: 'tests' stamp: 'ar 9/4/2010 11:25'!
testUrlEncoded
	"Test the behavior of #urlEncoded"

	self assert: 'http://squeak.org/name with space?and=value' urlEncoded
		equals: 'http://squeak.org/name%20with%20space?and=value'.

	self assert: 'http://squeak.org/name%20with%20space?and=value' urlEncoded
		equals: 'http://squeak.org/name%20with%20space?and=value'.

	self assert: 'http://squeak.org/name%with%space?and=value' urlEncoded
		equals: 'http://squeak.org/name%25with%25space?and=value'.
! !

!UrlTest methodsFor: 'tests' stamp: 'md 7/21/2003 10:48'!
testUsernamePassword

	"basic case with a username+password specified"
	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].

	"basic case for a relative url"
	baseUrl := 'http://anotherserver.blah:9999/somedir/someotherdir/stuff/' asUrl.
	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].

	"a true relative test that should keep the username and password from the base URL"
	baseUrl := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	url := '/anotherdir/stuff/' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'anotherdir' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].
	


	"just a username specified"
	url := 'http://user@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = nil ].


	"the port is not specified"
	url := 'http://user:pword@someserver.blah/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = nil ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].


	"neither a path nor a port is specified"
	url := 'http://user:pword@someserver.blah' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = nil ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].


	"relative URL where the username+password should be forgotten"
	baseUrl := 'http://user:pword@someserver.blah' asUrl.
	url := 'http://anotherserver.blah' asUrlRelativeTo: baseUrl.
	self should: [ url username = nil ].
	self should: [ url password = nil ].

! !

!UrlTest methodsFor: 'tests' stamp: 'topa 5/4/2010 14:33'!
testUsernamePasswordEncoded
	"Sometimes, weird usernames or passwords are necessary in 
	applications, and, thus, we might receive them in a Url.
	The @ and the : ar the kind of critical ones.
	"

	#(	"('user' 'pword' 'host' port 'path')"
		('Fürst Pückler' 'leckerEis' 'cottbus.brandenburg' 80 'mein/Zuhause')
		('Jeannde.d''Arc' 'jaiunesécret' 'orleans' 8080 'une/deux/trois')
		('HaXor@roxor:fnac' 'my~Pa$§wert' 'cbase' 42 'do/not_try')
	) do: [:urlParts | |theUrl|
		theUrl := ('http://{1}:{2}@{3}:{4}/{5}' format: {
			(urlParts at: 1) encodeForHTTP. 	(urlParts at: 2) encodeForHTTP.
			urlParts at: 3. urlParts at: 4. urlParts at: 5.
		}) asUrl.
		self 
			should: [theUrl schemeName = 'http'];
			should: [theUrl username = (urlParts at: 1)];
			should: [theUrl password = (urlParts at: 2)];
			should: [theUrl authority = (urlParts at: 3)];
			should: [theUrl port = (urlParts at: 4)];
			should: [theUrl path first = ((urlParts at: 5) copyUpTo: $/)]].
! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:22'!
testUsernamePasswordPrinting

	#(	'http://user:pword@someserver.blah:8000/root/index.html'
		'http://user@someserver.blah:8000/root/index.html' 
		'http://user:pword@someserver.blah/root/index.html'
	) do: [ :urlText |
		self should: [ urlText = urlText asUrl asString ] ].

! !

!UrlTest methodsFor: 'tests' stamp: 'topa 5/5/2010 13:50'!
testUsernamePasswordPrintingEncoded

	#(	'http://F%C3%BCrst%20P%C3%BCckler:leckerEis@cottbus.brandenburg:80/mein/Zuhause'
		'http://Jeannde.d%27Arc:jaiunes%C3%A9cret@orleans:8080/une/deux/trois' 
		'http://HaXor%40roxor%3Afnac:my%7EPa%24%C2%A7wert@cbase:42/do/not_try'
	) do: [ :urlText |
		self should: [ urlText = urlText asUrl asString ] ].

! !

Stream subclass: #MockSocketStream
	instanceVariableNames: 'binary atEnd inStream outStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!MockSocketStream class methodsFor: 'instance creation' stamp: 'fbs 3/22/2004 12:46'!
on: socket
	^self basicNew initialize! !

!MockSocketStream methodsFor: 'configuration' stamp: 'topa 10/14/2017 12:32'!
ascii

	binary := false.
	self refreshStreams.! !

!MockSocketStream methodsFor: 'testing' stamp: 'fbs 3/22/2004 13:08'!
atEnd
	^self inStream atEnd.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 12:51'!
atEnd: aBoolean
	atEnd := aBoolean.! !

!MockSocketStream methodsFor: 'configuration' stamp: 'topa 10/14/2017 12:32'!
binary

	binary := true.
	self refreshStreams.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:20'!
cr
	self nextPutAll: String cr! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:20'!
crlf
	self nextPutAll: String crlf! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:29'!
inStream
	^inStream! !

!MockSocketStream methodsFor: 'initialize-release' stamp: 'topa 10/14/2017 12:31'!
initialize
	binary := false.
	self resetInStream.
	self resetOutStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:20'!
next: n putAll: aCollection startingAt: startIndex

	^ self outStream next: n putAll: aCollection startingAt: startIndex
! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:10'!
nextLine
	^self nextLineCrLf! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
nextLineCrLf
	^(self upToAll: String crlf).! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:17'!
nextPut: anObject

	^ self outStream nextPut: anObject! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:18'!
nextPutAll: aCollection 
	^ self outStream nextPutAll: aCollection.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:18'!
nextPutAllFlush: aCollection 
	^ self outStream nextPutAll: aCollection.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:08'!
outStream
	^outStream! !

!MockSocketStream methodsFor: 'initialize-release' stamp: 'topa 10/14/2017 13:34'!
refreshStreams

	binary = self inStream isBinary ifFalse: [self resetInStream].
	binary = self outStream isBinary ifFalse: [self resetOutStream].
! !

!MockSocketStream methodsFor: 'stream in' stamp: 'topa 10/14/2017 13:35'!
resetInStream
	inStream := self streamSpecies new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 13:36'!
resetOutStream
	outStream := self streamSpecies new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'fbs 3/22/2004 13:07'!
sendCommand: aString
	self outStream
		nextPutAll: aString;
		nextPutAll: String crlf.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'topa 10/14/2017 14:20'!
space
	self nextPut: Character space! !

!MockSocketStream methodsFor: 'initialize-release' stamp: 'topa 10/14/2017 13:33'!
streamSpecies

	^ binary ifTrue: [ByteArray] ifFalse: [ByteString].
! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
upToAll: delims
	^self inStream upToAll: delims.! !

TestCase subclass: #MailAddressParserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-RFC822'!

!MailAddressParserTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class MailAddressParser. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- http://minnow.cc.gatech.edu/squeak/1547
	- the sunit class category!

!MailAddressParserTest methodsFor: 'fixtures' stamp: 'pre 9/6/2017 14:57'!
stringOfMailAddresses
	^ 'joe@lama.com, joe2@lama.com, joe3@lama.com, joe4 , Not an Address <joe5@address>, joe.(annoying (nested) comment)literal@[1.2.3.4], "an annoying" group : joe1@groupie, joe2@groupie, "Joey3" joe3@groupy, "joe6"."joe8"@group.com;,  Lex''s email account <lex>, foo+bar@baz.com, romeo&juliet@shakespeare.uk, "Name" mail@email.com'.! !

!MailAddressParserTest methodsFor: 'tests' stamp: 'pre 9/6/2017 14:57'!
testAddressesAndNamePairsIn

	| correctAnswer parsedParis |

	correctAnswer := #(
		('' 'joe@lama.com') 
		('' 'joe2@lama.com') 
		('' 'joe3@lama.com') 
		('' 'joe4')
		('Not an Address' 'joe5@address') 
		('' 'joe.literal@[1.2.3.4]') 
		('' 'joe1@groupie') 
		('' 'joe2@groupie') 
		('Joey3' 'joe3@groupy') 
		('' '"joe6"."joe8"@group.com')
		('Lex''s email account' 'lex')
		('' 'foo+bar@baz.com')
		('' 'romeo&juliet@shakespeare.uk')
		('Name' 'mail@email.com')) asOrderedCollection.

	parsedParis := MailAddressParser addressesAndNamePairsIn: self stringOfMailAddresses.
	self assert: correctAnswer equals: parsedParis.! !

!MailAddressParserTest methodsFor: 'tests' stamp: 'pre 9/6/2017 14:59'!
testAddressesIn

	| correctAnswer |

	correctAnswer := #(
		'joe@lama.com' 
		'joe2@lama.com' 
		'joe3@lama.com' 
		'joe4' 
		'joe5@address' 
		'joe.literal@[1.2.3.4]' 
		'joe1@groupie' 
		'joe2@groupie' 
		'joe3@groupy' 
		'"joe6"."joe8"@group.com' 
		'lex' 
		'foo+bar@baz.com' 
		'romeo&juliet@shakespeare.uk'
		'mail@email.com') asOrderedCollection.

	self assert: correctAnswer equals: (MailAddressParser addressesIn: self stringOfMailAddresses).! !

TestCase subclass: #MailDateAndTimeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-RFC822'!

!MailDateAndTimeTest methodsFor: 'tests' stamp: 'pre 12/7/2017 11:45'!
testBasicDate

	| date |
	date := DateAndTime year: 2017 month: 2 day: 3 hour: 0 minute: 0 second: 0 offset: (Duration hours: 0).
	self assert: 'Fri, 03 Feb 2017 00:00:00 +0000' equals: date asMailMessageString! !

!MailDateAndTimeTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:10'!
testBasicDateAndTime

	| date |
	date := DateAndTime year: 2000 month: 6 day: 22 hour: 14 minute: 17 second: 47 offset: (Duration days: 0 hours: -5 minutes: 0 seconds: 0 nanoSeconds:0).
	self assert: 'Thu, 22 Jun 2000 14:17:47 -0500' equals: date asMailMessageString
	! !

TestCase subclass: #MailMessageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-RFC822'!

!MailMessageTest commentStamp: 'tonyg 9/12/2011 09:17' prior: 0!
This is the unit test for the class MailMessage.!

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:23'!
fixtureMail
	
	^ MailMessage empty
		from: self fixtureSenderMail;
		to: self fixtureReceiverMails;
		messageId: self fixtureMessageId;
		dateTime: self fixtureMessageDate;
		subject: self fixtureSubject;
		yourself! !

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:14'!
fixtureMessageDate

	^ DateAndTime year: 2017 month: 2 day: 5 hour: 14 minute: 15 ! !

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:14'!
fixtureMessageId
	
	^ 'ijoisjdfoihasoidhfosihd@mail.com'! !

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:13'!
fixtureReceiverMails

	^ 'receiver@mail.com'! !

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:13'!
fixtureSenderMail

	^ 'sender@mail.com'! !

!MailMessageTest methodsFor: 'fixtures' stamp: 'pre 5/11/2017 16:24'!
fixtureSubject

	^ 'This is the subject'! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 12/7/2017 10:07'!
testAttachmentsGetTheirOwnContentType

	| message contentType |
	message := MailMessage empty 
		addAttachmentFrom: 'abcxxx' readStream withName: 'aTestingAttachment.pdf';
		body: ((MIMEDocument contentType: 'application/foo' content: 'This is the main text' squeakToUtf8) 
					charset: 'utf-8'; yourself).
		
	self assert: message attachments size equals: 1.

	contentType := (message attachments first fieldNamed: 'content-type' ifAbsent: [self fail])
					mainValue.
	self assert: contentType equals: 'application/pdf'.
			! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 12/7/2017 11:05'!
testAttachmentsReturnsTheAttachments

	| fileName message |
	message := MailMessage empty 
		addAttachmentFrom: 'abcxxx' readStream withName: 'aTestingAttachment';
		body: ((MIMEDocument contentType: 'application/foo' content: 'This is the main text' squeakToUtf8) 
					charset: 'utf-8'; yourself).
		
	self assert: 1 equals: message attachments size.

	fileName := (message attachments first fieldNamed: 'content-disposition' ifAbsent: [self fail])
					parameterAt: 'filename' ifAbsent: [''].
					
	self assert: fileName equals: '"aTestingAttachment"'.
	
	fileName := (message attachments first fieldNamed: 'content-type' ifAbsent: [self fail])
					parameterAt: 'name' ifAbsent: [''].
			
	self assert: fileName equals: '"aTestingAttachment"'.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 12/7/2017 10:00'!
testAttachmentsWorkWithVeryLongFilenames

	| fileName message |
	message := MailMessage empty 
		addAttachmentFrom: 'abcxxx' readStream withName: 'aTestingAttachmentWithAVeryVeryVeryVeryVeryVeryVeryVeryLongName.file';
		body: ((MIMEDocument contentType: 'application/foo' content: 'This is the main text' squeakToUtf8) 
					charset: 'utf-8'; yourself).
		
	self assert: message attachments size equals: 1.

	fileName := (message attachments first fieldNamed: 'content-disposition' ifAbsent: [self fail])
					parameterAt: 'filename' ifAbsent: [''].
					
	self assert: '"aTestingAttachmentWithAVeryVeryVeryVeryVeryVeryVeryVeryLongName.file"' equals: fileName 
			! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:18'!
testCreateAReplyForFrom

	| replyMail |
	replyMail := MailMessage replyFor: self fixtureMail.
	self assert: self fixtureSenderMail equals: replyMail to.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:28'!
testCreateAReplyForReplyTo

	| replyMail startMail |
	startMail := self fixtureMail
		setField: 'reply-to' toString: 'anothersender@mail.com';
		yourself.
	replyMail := MailMessage replyFor: startMail.
	self assert: 'anothersender@mail.com' equals: replyMail to.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 12/7/2017 11:55'!
testCreateAReplyForReplyTos

	| replyMail startMail |
	startMail := self fixtureMail
		setField: 'reply-to' toString: 'anothersender@mail.com, andanothersender@mail.com';
		yourself.
	replyMail := MailMessage replyFor: startMail.
	self 
		assert: {'anothersender@mail.com' . 'andanothersender@mail.com'} asSet
		equals: ((replyMail to findTokens: ',') collect: [:e | e withBlanksTrimmed]) asSet.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:24'!
testCreateAReplyHasANewSubject

	| replyMail |
	replyMail := MailMessage replyFor: self fixtureMail.
	self assert: 'Re: ' , self fixtureSubject equals: replyMail subject.! !

!MailMessageTest methodsFor: 'testing' stamp: 'pre 5/11/2017 16:25'!
testCreateAReplyHasANewSubjectUnlessWasAlreadyReply

	| replyMail startMail |
	startMail := self fixtureMail
		subject: 'Re: Subject';
		yourself.
	replyMail := MailMessage replyFor: startMail.
	self assert: 'Re: Subject' equals: replyMail subject.! !

!MailMessageTest methodsFor: 'tests' stamp: 'smalltalkCI 6/6/2017 14:30'!
testCreateMailMessage

	| newMail |
	newMail := MailMessage from: 'From: Al Gore <vicepresident@whitehouse.gov>
To: White House Transportation Coordinator <transport@whitehouse.gov>
Subject: [Map of a country]

there is a country map in this mail somewhere'.
	self assert: '[Map of a country]' equals: newMail subject! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/2/2019 15:12'!
testDateAndDateString

	| newMail |
	newMail := MailMessage from: 'From: Al Gore <vicepresident@whitehouse.gov>
To: White House Transportation Coordinator <transport@whitehouse.gov>
Subject: [Map of a country]
Date: Mon, 12 Aug 2002 17:42:00 +0000

there is a country map in this mail somewhere'.

	self assert: (DateAndTime year: 2002 month: 8 day: 12 hour: 17 minute: 42 second: 0 offset: Timespan defaultOffset) equals: newMail date.
	self assert: '8/12/02' equals: newMail dateString.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/2/2019 15:17'!
testDateStampFractionalSecondFormatting
	self 
		assert: (MailMessage dateStamp: (DateAndTime year: 1901 month: 1 day: 1 hour: 0 minute: 0 second: 1.234 offset: Timespan defaultOffset))
		equals:  'Tue, 1 Jan 1901 00:00:01'
		description: 'RFC822 (and RFC2822) forbids non-integer seconds in dates'! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:32'!
testReplyContainsInReplyTo

	| replyMail |
	replyMail := MailMessage replyFor: self fixtureMail.
	self assert: self fixtureMessageId equals: (replyMail fieldNamed: 'in-reply-to' ifAbsent: [self fail]) mainValue.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 5/11/2017 16:43'!
testReplyContainsReferences

	| replyMail lastReply |
	replyMail := MailMessage replyFor: self fixtureMail.
	replyMail
		setField: 'message-id' toString: 'abc';
		from: 'me@mail.com'.
	lastReply := MailMessage replyFor: replyMail.
	
	self 
		assert: self fixtureMessageId , ', abc' 
		equals: (lastReply fieldNamed: 'references' ifAbsent: [self fail]) mainValue.! !

!MailMessageTest methodsFor: 'tests' stamp: 'pre 2/23/2018 19:57'!
testSendableVersionHasCorrectLineBreaks

	| newMail longContent |
	"To create a string which is too long to very old recommendations
	of the mail message format, which is about 70 characters."
	longContent := ((1 to: 80) do: [:i | i asString]) joinSeparatedBy: ''.
	newMail := self fixtureMail.
	newMail body: ((MIMEDocument 
		contentType: MIMEDocument contentTypePlainText
		content: longContent)
			charset: 'UTF-8';
			yourself).
	newMail := MailMessage from: newMail asSendableText.
	self assert: (newMail bodyTextFormatted asString includesSubstring: longContent)! !

TestCase subclass: #SMTPClientTest
	instanceVariableNames: 'smtp socket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Protocols'!

!SMTPClientTest methodsFor: 'running' stamp: 'fbs 3/22/2004 13:11'!
setUp
	socket := MockSocketStream on: ''.
	smtp := SMTPClient new.
	smtp stream: socket.! !

!SMTPClientTest methodsFor: 'tests' stamp: 'fbs 3/23/2004 17:15'!
testMailFrom
	smtp mailFrom: 'frank@angband.za.org'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: '<frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: 'Frank <frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).! !

TestCase subclass: #SocketTest
	instanceVariableNames: 'listenerSocket clientSocket serverSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!SocketTest methodsFor: 'failures' stamp: 'mt 8/16/2016 10:45'!
expectedFailures

	^ Smalltalk platformName = 'Win32'
		ifTrue: [#(testSocketReuse)]
		ifFalse: [#()]! !

!SocketTest methodsFor: 'fixtures' stamp: 'topa 9/8/2015 00:02'!
listenerAddress
	^NetNameResolver addressForName: 'localhost'
! !

!SocketTest methodsFor: 'fixtures' stamp: 'eem 9/25/2020 13:10'!
listenerAddressForFamily: addressFamily
	^NetNameResolver addressForName: 'localhost' family: addressFamily! !

!SocketTest methodsFor: 'fixtures' stamp: 'ar 11/26/2010 10:13'!
listenerPort
	^42324
! !

!SocketTest methodsFor: 'running' stamp: 'ar 11/26/2010 10:24'!
setUp

	listenerSocket := Socket newTCP listenOn: self listenerPort backlogSize: 4 interface: self listenerAddress.
! !

!SocketTest methodsFor: 'running' stamp: 'ar 11/26/2010 10:24'!
tearDown

	listenerSocket ifNotNil:[listenerSocket destroy].
	clientSocket ifNotNil:[clientSocket destroy].
	serverSocket ifNotNil:[serverSocket destroy].
! !

!SocketTest methodsFor: 'tests' stamp: 'eem 9/25/2020 13:07'!
testClientConnect
	"Tests a client socket connection"

	clientSocket := Socket newTCP.
	clientSocket connectTo: (self listenerAddressForFamily: clientSocket addressFamily) port: self listenerPort.
	clientSocket waitForConnectionFor: 2.
	self assert: clientSocket isConnected! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 11:08'!
testDataReceive
	"Test data transfer and related methods"

	self testDataSending.
	"It can take a tad for the status change to be visible"
	(Delay forMilliseconds: 200) wait.
	self assert: serverSocket dataAvailable.
	self assert: (serverSocket receiveData = 'Hello World').
	self deny: (serverSocket dataAvailable).
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 11:06'!
testDataSending
	"Test data transfer and related methods"

	self testServerAccept.
	clientSocket sendData: 'Hello World'.
	clientSocket waitForSendDoneFor: 2.
	self assert: clientSocket sendDone.

! !

!SocketTest methodsFor: 'tests' stamp: 'eem 9/25/2020 13:09'!
testLocalAddress
	"Tests the various localAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket localAddress equals: (self listenerAddressForFamily: listenerSocket addressFamily).
	self assert: clientSocket localAddress equals: (self listenerAddressForFamily: clientSocket addressFamily).
	self assert: serverSocket localAddress equals: (self listenerAddressForFamily: serverSocket addressFamily)! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testLocalPort
	"Tests the various localPort values for sockets"

	self testServerAccept.
	self assert: listenerSocket localPort = self listenerPort.
	self assert: clientSocket localPort > 0.
	self assert: serverSocket localPort > 0.
! !

!SocketTest methodsFor: 'tests' stamp: 'topa 9/7/2015 23:39'!
testPeerName
	"None of these should throw an exception."
	"This can actually take a while, depending on networks availability"
	<timeout: 30>

	Socket new peerName.
	self testServerAccept.
	listenerSocket peerName.
	clientSocket peerName.
	serverSocket peerName.! !

!SocketTest methodsFor: 'tests' stamp: 'ar 9/4/2011 15:45'!
testReceiveTimeout
	"Test data transfer and related methods"

	self testServerAccept.
	self assert: (serverSocket receiveDataTimeout: 1) isEmpty.! !

!SocketTest methodsFor: 'tests' stamp: 'dtl 6/3/2012 19:23'!
testRemoteAddress
	"Tests the various remoteAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket remoteAddress asByteArray = #[0 0 0 0].
	self assert: clientSocket remoteAddress = self listenerAddress.
	self assert: serverSocket remoteAddress = self listenerAddress.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testRemotePort
	"Tests the various remoteAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket remotePort = 0.
	self assert: clientSocket remotePort = self listenerPort.
	self assert: serverSocket remotePort > 0.
! !

!SocketTest methodsFor: 'tests' stamp: 'dtl 11/3/2012 14:11'!
testSendTimeout
	"Test data transfer and related methods"

	| buffer ex |
	self testServerAccept.
	buffer := ByteArray new: 1000.

	"Write to the socket until the platform reports that sending is not complete."
	[serverSocket sendDone] whileTrue:[
		serverSocket sendSomeData: buffer.
	].

	"The network layer is now either blocked or in the process of sending data in its buffers.
	It may or may not be able buffer additional write requests, depending on the platform
	implemention. Keep sending data until the network reports that it is unable to process
	the request, at which time a exception will be raised. On Windows, the exception will
	be raised on the next write request, while unix platforms may provide additional buffering
	that permit write requests to continue being accepted."
	ex := nil.
	[[serverSocket sendSomeData: buffer startIndex: 1 count: buffer size for: 1]
		on: ConnectionTimedOut
		do: [ :e | ex := e ].
	ex isNil] whileTrue: [].
	self assert: ex notNil.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testServerAccept
	"Tests a server-side accept"

	self testClientConnect.
	serverSocket := listenerSocket waitForAcceptFor: 2.
	self assert: (serverSocket notNil).
	self assert: (serverSocket isConnected).
! !

!SocketTest methodsFor: 'tests' stamp: 'eem 10/9/2020 01:19'!
testSocketReuse
	"Test for SO_REUSEADDR/SO_REUSEPORT. Should probably be called testUDPSocketReuse.
	 c.f. testTCPSocketReuse"

	| udp1 udp2 sendProc recvProc  |
	[
		| address port opt send1 recv2 received sent |
		address := #[255 255 255 255]. "broadcast"
		port := 31259.
		udp1 := Socket newUDP.
		udp1 setOption: 'SO_REUSEADDR' value: 1.
		self assert: 0 equals: udp1 socketError description: 'Error occured while setting SO_REUSEADDR'.
		opt := udp1 getOption: 'SO_REUSEADDR'.
		self assert: opt first isZero & opt last isZero not description: 'SO_REUSEADDR couldn''t be set'.
		udp1 setOption: 'SO_REUSEPORT' value: 1.
		self assert: 0 equals: udp1 socketError description: 'Error occured while setting SO_REUSEPORT'.
		opt := udp1 getOption: 'SO_REUSEPORT'.
		self assert: opt first isZero & opt last isZero not description: 'SO_REUSEPORT couldn''t be set'.
		udp1 setPort: port.
		self assert: port equals: udp1 localPort.
		udp1 setOption: 'SO_BROADCAST' value: 1.
		send1 := UUID new.

		udp2 := Socket newUDP.
		udp2 setOption: 'SO_REUSEADDR' value: 1.
		self assert: 0 equals: udp2 socketError.
		udp2 setOption: 'SO_REUSEPORT' value: 1.
		self assert: 0 equals: udp2 socketError.
		udp2 setPort: port.
		self assert: port equals: udp2 localPort.
		udp2 setOption: 'SO_BROADCAST' value: 1.
		recv2 := UUID new.

		received := 0.
		recvProc := [
			[received < 16] whileTrue:[
				received := received + (udp2 receiveDataInto: recv2 startingAt: received + 1)
				"No need to yield here, because #receiveDataInto:startingAt: will either wait on the readSemaphore of the socket or signal an error." ]
			] newProcess.
		sendProc := [
			udp1 setPeer: address port: port.
			sent := (udp1 sendSomeData: send1 startIndex: 1 count: 16 for: 1).
		] newProcess.
		recvProc resume.
		sendProc resume.
		(Delay forMilliseconds: 200) wait.
		self 
			assert: sendProc isTerminated description: 'sendProc hasn''t terminated till the deadline';
			assert: recvProc isTerminated description: 'recvProc hasn''t terminated till the deadline';
			assert: 16 equals: sent description: ('{1} bytes were sent instead of 16' format: { sent });
			assert: send1 equals: recv2  description: 'sent and received bytes differ'
	] ensure:[ 
		udp1 ifNotNil: [ udp1 destroy ].
		udp2 ifNotNil: [ udp2 destroy ].
		sendProc ifNotNil: [ sendProc terminate ].
		recvProc ifNotNil: [ recvProc terminate ]
	].
! !

!SocketTest methodsFor: 'tests' stamp: 'dtl 7/17/2012 08:08'!
testStringFromAddress
	"Addresses are represented by a ByteArray if NetNameResolver useOldNetwork
	is true, or by by SocketAddress otherwise. Ensure the #stringFromAddress: works
	in either case. Older versions of SocketPlugin in the VM do not provide support
	for SocketAddress, and ByteArray addresses are used in that case."

	| localAddress localAddressBytes localName1 localName2 |
	localAddress := NetNameResolver localHostAddress. "ByteArray or SocketAddress"
	localAddressBytes := localAddress asByteArray.
	localName1 := NetNameResolver stringFromAddress: localAddress.
	localName2 := NetNameResolver stringFromAddress: localAddressBytes.
	self assert: localName1 = localName2
! !

!SocketTest methodsFor: 'tests' stamp: 'eem 10/9/2020 01:17'!
testTCPSocketReuse
	"Test for SO_REUSEADDR/SO_REUSEPORT using TCP sockets.  c.f. testSocketReuse"

	| tcpSend tcpRecv sendProcess recvProcess  |
	[
		|  address port opt send1 recv2 sent |
		address := NetNameResolver addressForName: '127.0.0.1' timeout: 20.
		port := 31259.
		tcpSend := Socket newTCP.
		tcpSend setOption: 'SO_REUSEADDR' value: 1.
		self assert: 0 equals: tcpSend socketError description: 'Error occured while setting SO_REUSEADDR'.
		opt := tcpSend getOption: 'SO_REUSEADDR'.
		self assert: opt first isZero & opt last isZero not description: 'SO_REUSEADDR couldn''t be set'.
		tcpSend setOption: 'SO_REUSEPORT' value: 1.
		self assert: 0 equals: tcpSend socketError description: 'Error occured while setting SO_REUSEPORT'.
		opt := tcpSend getOption: 'SO_REUSEPORT'.
		self assert: opt first isZero & opt last isZero not description: 'SO_REUSEPORT couldn''t be set'.
		"tcpSend setOption: 'TCP_NODELAY' value: 1."
		send1 := UUID new.

		tcpRecv := Socket newTCP.
		tcpRecv setOption: 'SO_REUSEADDR' value: 1.
		self assert: 0 equals: tcpRecv socketError.
		tcpRecv setOption: 'SO_REUSEPORT' value: 1.
		self assert: 0 equals: tcpRecv socketError.
		tcpRecv setPort: port.
		self assert: port equals: tcpRecv localPort.
		recv2 := UUID new.

		[| received |
		 recvProcess := Processor activeProcess.
		 received := 0.
		 tcpRecv waitForConnectionFor: 200.
		 [received < 16] whileTrue:
			["No need to yield here, because #receiveDataInto:startingAt: will either wait on the readSemaphore of the socket or signal an error." 
			 received := received + (tcpRecv receiveDataInto: recv2 startingAt: received + 1)]] fork.
		[sendProcess := Processor activeProcess.
		 tcpSend connectTo: address port: port.
		 sent := tcpSend sendData: send1] fork.
		(Delay forMilliseconds: 200) wait.
		self 
			assert: sendProcess isTerminated description: 'sendProc hasn''t terminated till the deadline';
			assert: recvProcess isTerminated description: 'recvProc hasn''t terminated till the deadline';
			assert: 16 equals: sent description: ('{1} bytes were sent instead of 16' format: { sent });
			assert: send1 equals: recv2  description: 'sent and received bytes differ']
	ensure:
		[tcpSend ifNotNil: [ tcpSend destroy ].
		tcpRecv ifNotNil: [ tcpRecv destroy ].
		sendProcess ifNotNil: [ sendProcess terminate ].
		recvProcess ifNotNil: [ recvProcess terminate ]]! !

!SocketTest methodsFor: 'tests' stamp: 'ar 9/4/2011 15:50'!
testUDP
	"Test udp recv() and send() functionality"

	serverSocket := Socket newUDP.
	serverSocket setPort: 54321.

	clientSocket := Socket newUDP.
	clientSocket setPeer: NetNameResolver localHostAddress port: serverSocket port.
	clientSocket sendData: 'Hello World'.

	(Delay forMilliseconds: 200) wait.

	self assert: (serverSocket dataAvailable).
	self assert: (serverSocket receiveData = 'Hello World').
! !

TestCase subclass: #UUIDPrimitivesTest
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'NetworkTests-UUID'!

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:14'!
testCreation
	| uuid |
	uuid := UUID new.
	self should: [uuid size = 16].
	self shouldnt: [uuid isNilUUID].
	self should: [uuid asString size = 36].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:27'!
testCreationEquality
	| uuid1 uuid2 |
	uuid1 := UUID new.
	uuid2 := UUID new.
	self should: [uuid1 = uuid1].
	self should: [uuid2 = uuid2].
	self shouldnt: [uuid1 = uuid2].
	self shouldnt: [uuid1 hash = uuid2 hash].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:17'!
testCreationFromString
	| uuid string |
	string := UUID nilUUID asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid = UUID nilUUID].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:18'!
testCreationFromStringNotNil
	| uuid string |
	string := UUID new asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid asString size = 36].

! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:16'!
testCreationNil
	| uuid |
	uuid := UUID nilUUID.
	self should: [uuid size = 16].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 12/27/2009 04:14'!
testCreationNodeBased
	

	(UUID new asString last: 12) = (UUID new asString last: 12) ifFalse: [^self].
	1000 timesRepeat:
		[ | uuid |
		uuid := UUID new.
		self should: [((uuid at: 7) bitAnd: 16rF0) = 16r10].
		self should: [((uuid at: 9) bitAnd: 16rC0) = 16r80]]
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 12/27/2009 04:15'!
testDuplicationsKinda
	| check size |

	size := 5000.
	check := Set new: size.
	size timesRepeat: 
		[ | uuid |
		uuid := UUID new.
		self shouldnt: [check includes: uuid].
		check add: uuid].
		! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 12/27/2009 04:15'!
testOrder
	
	100 timesRepeat:
		[ | uuid1 uuid2 |
		uuid1 := UUID new.
		uuid2 := UUID new.
		(uuid1 asString last: 12) = (uuid2 asString last: 12) ifTrue:
			[self should: [uuid1 < uuid2].
			self should: [uuid2 > uuid1].
			self shouldnt: [uuid1 = uuid2]]]
! !

TestCase subclass: #UUIDTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-UUID'!

!UUIDTest methodsFor: 'tests' stamp: 'ul 11/9/2011 23:58'!
testComparison
	"Test if the comparison operators define a total sort function."

	#(
		#[3 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0] #[2 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0]
		#[0 0 0 0 0 0 0 0 0 0 0 0 0 0 3 1] #[0 0 0 0 0 0 0 0 0 0 0 0 0 0 2 4]
		#[2 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0] #[3 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0]
		#[0 0 0 0 0 0 0 0 0 0 0 0 0 0 2 4] #[0 0 0 0 0 0 0 0 0 0 0 0 0 0 3 1]
		#[0 0 0 0 0 0 0 0 0 0 0 0 0 0 2 4] #[0 0 0 0 0 0 0 0 0 0 0 0 0 0 2 4]
	) pairsDo: [ :x :y |
		| a b c d |
		a := UUID newFrom: x.
		b := UUID newFrom: y.
		c := x asString.
		d := y asString.
		"Check if the comparison is lexicographical, just like strings'."
		#(< > <= >= = ~=) do: [ :operation | 
			self assert: (a perform: operation with: b) = (c perform: operation with: d) ].
		"And a few more"
		self
			assert: (a < b) = (a >= b) not;
			assert: (a > b) = (a <= b) not;
			assert: (a = b) = (a ~= b) not;
			assert: (a < b) = (b > a);
			assert: (a > b) = (b < a);
			assert: (a >= b) = (b <= a);
			assert: (a <= b) = (b >= a);
			assert: (a = b) = (b = a);
			assert: (a ~= b) = (b ~= a);
			assert: (a > b) = ((a >= b) & (a ~= b));
			assert: (a < b) = ((a <= b) & (a ~= b));
			assert: (a >= b) = ((a = b) | (a > b));
			assert: (a <= b) = ((a = b) | (a < b));
			assert: (a ~= b) = ((a < b) | (a > b));
			assert: (a <= b) & (b <= a) = (a = b);
			assert: (a >= b) & (b >= a) = (a = b);
			assert: (a <= b) | (b <= a);
			assert: (a = b) asBit + (a < b) asBit + (b < a) asBit = 1 ]! !
